==> flink-1.15.1-src.tgz: flink-1.15.1/flink-table/flink-table-api-java-bridge/src/main/java/org/apache/flink/table/connector/ProviderContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.connector;

import org.apache.flink.annotation.PublicEvolving;
import org.apache.flink.api.dag.Transformation;
import org.apache.flink.streaming.api.datastream.DataStream;
import org.apache.flink.table.connector.sink.DynamicTableSink.SinkRuntimeProvider;
import org.apache.flink.table.connector.source.ScanTableSource.ScanRuntimeProvider;

import java.util.Optional;

/**
 * Context provided by some {@link ScanRuntimeProvider} and {@link SinkRuntimeProvider} with
 * utilities for generating the runtime implementation.
 */
@PublicEvolving
public interface ProviderContext {

    /**
     * Generates a new unique identifier for a {@link Transformation}/{@link DataStream} operator.
     * The {@code name} must be unique within the provider implementation. The framework will make
     * sure that the name is unique for the entire topology.
     *
     * <p>This method returns empty if an identifier cannot be generated, i.e. because the job is in
     * batch mode.
     */
    Optional<String> generateUid(String name);
}

==> flink-1.19.3-src.tgz: flink-1.19.3/flink-table/flink-table-api-java-bridge/src/main/java/org/apache/flink/table/connector/ProviderContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.connector;

import org.apache.flink.annotation.PublicEvolving;
import org.apache.flink.api.dag.Transformation;
import org.apache.flink.streaming.api.datastream.DataStream;
import org.apache.flink.table.connector.sink.DynamicTableSink.SinkRuntimeProvider;
import org.apache.flink.table.connector.source.ScanTableSource.ScanRuntimeProvider;

import java.util.Optional;

/**
 * Context provided by some {@link ScanRuntimeProvider} and {@link SinkRuntimeProvider} with
 * utilities for generating the runtime implementation.
 */
@PublicEvolving
public interface ProviderContext {

    /**
     * Generates a new unique identifier for a {@link Transformation}/{@link DataStream} operator.
     * The {@code name} must be unique within the provider implementation. The framework will make
     * sure that the name is unique for the entire topology.
     *
     * <p>This method returns empty if an identifier cannot be generated, i.e., because the job is
     * in batch mode, or UIDs cannot be guaranteed to be unique.
     */
    Optional<String> generateUid(String name);
}
